package sun.management;

import java.lang.management.MemoryUsage;
import javax.management.openmbean.OpenDataException;
import javax.management.openmbean.CompositeDataSupport;
import javax.management.openmbean.CompositeData;
import javax.management.openmbean.CompositeType;
import java.lang.management.MemoryNotificationInfo;

public class MemoryNotifInfoCompositeData extends LazyCompositeData
{
    private final MemoryNotificationInfo memoryNotifInfo;
    private static final CompositeType memoryNotifInfoCompositeType;
    private static final String POOL_NAME = "poolName";
    private static final String USAGE = "usage";
    private static final String COUNT = "count";
    private static final String[] memoryNotifInfoItemNames;
    private static final long serialVersionUID = -1805123446483771291L;
    
    private MemoryNotifInfoCompositeData(MemoryNotificationInfo memoryNotifInfo) {
        this.memoryNotifInfo = memoryNotifInfo;
    }
    
    public MemoryNotificationInfo getMemoryNotifInfo() {
        return this.memoryNotifInfo;
    }
    
    public static CompositeData toCompositeData(MemoryNotificationInfo memoryNotificationInfo) {
        return new MemoryNotifInfoCompositeData(memoryNotificationInfo).getCompositeData();
    }
    
    @Override
    protected CompositeData getCompositeData() {
        Object[] itemValues = { this.memoryNotifInfo.getPoolName(), MemoryUsageCompositeData.toCompositeData(this.memoryNotifInfo.getUsage()), new Long(this.memoryNotifInfo.getCount()) };
        try {
            return new CompositeDataSupport(MemoryNotifInfoCompositeData.memoryNotifInfoCompositeType, MemoryNotifInfoCompositeData.memoryNotifInfoItemNames, itemValues);
        }
        catch (OpenDataException detailMessage) {
            throw new AssertionError(detailMessage);
        }
    }
    
    public static String getPoolName(CompositeData compositeData) {
        String string = LazyCompositeData.getString(compositeData, "poolName");
        if (string == null) {
            throw new IllegalArgumentException("Invalid composite data: Attribute poolName has null value");
        }
        return string;
    }
    
    public static MemoryUsage getUsage(CompositeData compositeData) {
        return MemoryUsage.from((CompositeData)compositeData.get("usage"));
    }
    
    public static long getCount(CompositeData compositeData) {
        return LazyCompositeData.getLong(compositeData, "count");
    }
    
    public static void validateCompositeData(CompositeData compositeData) {
        if (compositeData == null) {
            throw new NullPointerException("Null CompositeData");
        }
        if (!LazyCompositeData.isTypeMatched(MemoryNotifInfoCompositeData.memoryNotifInfoCompositeType, compositeData.getCompositeType())) {
            throw new IllegalArgumentException("Unexpected composite type for MemoryNotificationInfo");
        }
        return;
    }
    
    static {
        try {
            memoryNotifInfoCompositeType = (CompositeType)MappedMXBeanType.toOpenType(MemoryNotificationInfo.class);
        }
        catch (OpenDataException detailMessage) {
            throw new AssertionError(detailMessage);
        }
        memoryNotifInfoItemNames = new String[] { "poolName", "usage", "count" };
    }
}
